@@ -26,7 +26,7 @@
 #  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 #  SUCH DAMAGE.
 
-# $XFree86: doctools/sgmlformat/sgmlfmt/sgmlfmt.pl,v 1.15 2000/01/20 23:14:29 dawes Exp $
+# $XFree86: doctools/sgmlformat/sgmlfmt/sgmlfmt.pl,v 1.16 2000/06/14 01:50:53 dawes Exp $
 
 # Format an sgml document tagged according to the linuxdoc DTD.
 # by John Fieber <jfieber@freebsd.org> for the FreeBSD documentation
@@ -765,12 +765,9 @@ sub main {
     else {
     	$dtd = "linuxdoc";
     	$decl = "-c " . $sgmldir . "/linuxdoc/catalog";
-	if ( $opt_f eq "nippon") {
-		$dtd = "linuxdoctr";
-	}
     }
 
-    if ($opt_b) {
+    if ($opt_b || $opt_f eq "nippon" || $opt_e eq "euc-jp") {
 	$colcmd = "col -bx";
     }
     else {
